@@ -13,7 +13,7 @@
 ##############################################################################
 """Zope publication
 
-$Id: zopepublication.py 102723 2009-08-13 01:22:26Z gary $
+$Id: zopepublication.py 91191 2008-09-16 15:06:24Z asmith $
 """
 __docformat__ = 'restructuredtext'
 
@@ -39,13 +39,13 @@ from zope.location import LocationProxy
 from zope.error.interfaces import IErrorReportingUtility
 
 import zope.app.security.interfaces
-from zope.app import zapi
 from zope.app.applicationcontrol.applicationcontrol \
      import applicationControllerRoot
 from zope.app.exception.interfaces import ISystemErrorView
 from zope.app.publication.interfaces import BeforeTraverseEvent
 from zope.app.publication.interfaces import EndRequestEvent
 from zope.app.publication.publicationtraverse import PublicationTraverse
+from zope.app.publisher.browser import queryDefaultViewName
 from zope.app.security.interfaces import IUnauthenticatedPrincipal
 from zope.app.security.interfaces import IFallbackUnauthenticatedPrincipal
 from zope.app.security.interfaces import IAuthentication
@@ -72,7 +72,6 @@ class ZopePublication(PublicationTraverse):
     """Base Zope publication specification."""
     implements(IPublication)
 
-    version_cookie = 'Zope-Version'
     root_name = 'Application'
 
     def __init__(self, db):
@@ -146,12 +145,12 @@ class ZopePublication(PublicationTraverse):
             return applicationControllerRoot
 
         # Open the database.
-        version = request.get(self.version_cookie, '')
-        conn = self.db.open(version)
+        conn = self.db.open()
 
         cleanup = Cleanup(conn.close)
         request.hold(cleanup)  # Close the connection on request.close()
 
+        request.annotations['ZODB.interfaces.IConnection'] = conn
         self.openedConnection(conn)
         #conn.setDebugInfo(getattr(request, 'environ', None), request.other)
 
@@ -222,7 +221,7 @@ class ZopePublication(PublicationTraverse):
         self.beginErrorHandlingTransaction(request, object,
                                            'error reporting utility')
         try:
-            errUtility = zapi.getUtility(IErrorReportingUtility)
+            errUtility = zope.component.getUtility(IErrorReportingUtility)
 
             # It is important that an error in errUtility.raising
             # does not propagate outside of here. Otherwise, nothing
@@ -248,12 +247,7 @@ class ZopePublication(PublicationTraverse):
     def handleException(self, object, request, exc_info, retry_allowed=True):
         # This transaction had an exception that reached the publisher.
         # It must definitely be aborted.
-        try:
-            transaction.abort()
-        except:
-            # Hm, a catastrophe.  We might want to know what preceded it.
-            self._logErrorWithErrorReportingUtility(object, request, exc_info)
-            raise
+        transaction.abort()
 
         # Reraise Retry exceptions for the publisher to deal with.
         if retry_allowed and isinstance(exc_info[1], Retry):
@@ -273,7 +267,7 @@ class ZopePublication(PublicationTraverse):
         # handling determine whether a retry is allowed or not?
         # Assume not for now.
 
-        # Record the error with the ErrorReportingUtility.
+        # Record the error with the ErrorReportingUtility
         self._logErrorWithErrorReportingUtility(object, request, exc_info)
 
         response = request.response
@@ -320,9 +314,9 @@ class ZopePublication(PublicationTraverse):
                 # Give the exception instance its location and look up the
                 # view.
                 exception = LocationProxy(exc_info[1], loc, '')
-                name = zapi.queryDefaultViewName(exception, request)
+                name = queryDefaultViewName(exception, request)
                 if name is not None:
-                    view = zapi.queryMultiAdapter(
+                    view = zope.component.queryMultiAdapter(
                         (exception, request), name=name)
             except:
                 # Problem getting a view for this exception. Log an error.
